@@ -50,7 +50,7 @@ from struct import pack, unpack
 from time import sleep
 
 # Constants
-LOCAL_PORT_AGENT = 44191  # the local port the agent uses to listen for instructions from Machine.
+LOCAL_PORT_AGENT = 44191  # the local port the agent uses to listen for instructions from Assistant.
 # IMPORTANT NOTE: the ports used by Tor, File, and Interactive mode on destination host (*here*)
 #   are sent by a subclass of the AgentAssistant class
 
@@ -67,7 +67,7 @@ ATYP_DOMAINNAME = b'\x03'  # DOMAINNAME '03'
 
 # Logging
 LOGGER = logging.getLogger()  # not used?
-LOGGER_BASENAME = '''agent'''
+LOGGER_BASENAME = '''Agent'''
 
 
 def validate_http_instruction(request):
@@ -110,13 +110,13 @@ class LoggerMixin:  # pylint: disable=too-few-public-methods
 
 
 class Agent(LoggerMixin):
-    """Listens for instructions send by Machine."""
+    """Listens for instructions send by Assistant."""
 
     def __init__(self, local_port_agent):
         """Initialize the Agent object.
 
         Args:
-            local_port_agent (basestring): The local port used to listen for instructions from Machine.
+            local_port_agent (basestring): The local port used to listen for instructions from Assistant.
 
         """
         super().__init__()
@@ -150,7 +150,7 @@ class Agent(LoggerMixin):
                 """Creates the response."""
                 try:
                     data = self.rfile.read(int(self.headers['Content-Length']))  # b'{"process":"heartbeat_responder"}
-                    self._logger.debug('the following request was received from Machine: %s', data)
+                    self._logger.debug('the following request was received from Assistant: %s', data)
                     instruction_string = data.decode('utf-8')  # convert byte to string (JSON format)
                     instruction_dict = json.loads(instruction_string)  # convert JSON to dict
                     # example: {'process': 'authenticate_host', 'arguments': {'hostname': 'server.example.com'}}
@@ -201,7 +201,7 @@ class Agent(LoggerMixin):
         return True
 
     # def authenticate_host(self, **kwargs):
-    #     """Authenticate Machine."""
+    #     """Authenticate host."""
     #     hostname = kwargs.get('hostname')
     #     self.authenticate = Authenticate(expected_hostname=hostname)
     #     return self.authenticate.start()
@@ -218,12 +218,12 @@ class Agent(LoggerMixin):
 
     def proxy_server_start(self, **kwargs):
         """Starts the proxy server."""
-        local_addr_i = '127.0.0.1'
-        local_port = kwargs.get('local_port')
-        ip_address_e = kwargs.get('ip_address_e')
+        local_addr_i = kwargs.get('remote_address_i')
+        local_port_i = kwargs.get('remote_port_i')
+        local_addr_e = kwargs.get('remote_address_e')
         self.proxy_server = ProxyServer(local_addr_i=local_addr_i,
-                                        local_port=local_port,
-                                        local_addr_e=ip_address_e)
+                                        local_port_i=local_port_i,
+                                        local_addr_e=local_addr_e)
         return self.proxy_server.start()
 
     def proxy_server_stop(self):
@@ -380,7 +380,7 @@ class DataProtocol(LoggerMixin):  # --> Give thoughts about if FileServer should
 
 
 class CommandServer(LoggerMixin):  # implementation follows in next release -- WHAT IMPLEMENTATION?
-    """Listens for Linux commands send by InteractiveMachine() and responds with result."""
+    """Listens for Linux commands send by InteractiveAssistant() and responds with result."""
 
     #  determine first whether port is bind or not
     #  < code >
@@ -422,12 +422,12 @@ class CommandServer(LoggerMixin):  # implementation follows in next release -- W
                 """Creates the response containing the result."""
                 try:
                     data = self.rfile.read(int(self.headers['Content-Length']))  # b'{"command":"ls -l /"}
-                    self._logger.debug('following raw Linux command was received from assistant: %s', data)
+                    self._logger.debug('following raw Linux command was received from instructor: %s', data)
                     command_string = data.decode('utf-8')  # convert byte to string in JSON format
                     command_dict = json.loads(command_string)  # convert JSON to dict
                     command_val = validate_http_command(command_dict)  # validate the structure of the content of req.
                     command = command_val.get('command')
-                    instance._logger.debug('following Linux command was received from assistant: %s', command)
+                    instance._logger.debug('following Linux command was received from instructor: %s', command)
                     # eg. b'{"command": "hostname"}'
                 except json.decoder.JSONDecodeError:  # json.loads()
                     self._logger.error('the content is incorrectly parsed in JSON')
@@ -679,11 +679,11 @@ class ProxyServer(LoggerMixin):
 
     """
 
-    def __init__(self, local_addr_i, local_port, local_addr_e=None):
+    def __init__(self, local_addr_i, local_port_i, local_addr_e=None):
         """Initializes a Proxy object."""
         super().__init__()
         self.local_addr_i = local_addr_i
-        self.local_port = local_port
+        self.local_port_i = local_port_i
         self.local_addr_e = local_addr_e
         self.new_socket = None
         self.thread = None
@@ -691,7 +691,7 @@ class ProxyServer(LoggerMixin):
     def start(self):
         """Starts the SOCKS proxy server."""
         try:
-            self.new_socket = SocketServerInternal(self.local_addr_i, self.local_port)
+            self.new_socket = SocketServerInternal(self.local_addr_i, self.local_port_i)
             self.new_socket.create_socket_and_listen()
             self.thread = threading.Thread(target=self._execution)
             self.thread.start()
